@@ -11,7 +11,8 @@ from pulpcore.plugin.serializers import (
     RepositorySerializer,
     RepositorySyncURLSerializer,
     SingleArtifactContentSerializer,
-    RepositoryVersionDistributionSerializer,
+    DistributionSerializer,
+    RepositoryVersionRelatedField,
     validate_unknown_fields,
 )
 
@@ -134,6 +135,12 @@ class CollectionRemoteSerializer(RemoteSerializer):
         max_length=2000,
     )
 
+    sync_dependencies = serializers.BooleanField(
+        help_text=_("Sync dependencies for collections specified via requirements file"),
+        allow_null=True,
+        default=True,
+    )
+
     def validate(self, data):
         """
         Validate collection remote data.
@@ -183,6 +190,7 @@ class CollectionRemoteSerializer(RemoteSerializer):
             "requirements_file",
             "auth_url",
             "token",
+            "sync_dependencies",
         )
         model = CollectionRemote
 
@@ -228,7 +236,7 @@ class CollectionOneShotSerializer(serializers.Serializer):
     )
 
 
-class AnsibleDistributionSerializer(RepositoryVersionDistributionSerializer):
+class AnsibleDistributionSerializer(DistributionSerializer):
     """
     Serializer for Ansible Distributions.
     """
@@ -236,6 +244,9 @@ class AnsibleDistributionSerializer(RepositoryVersionDistributionSerializer):
     client_url = serializers.SerializerMethodField(
         read_only=True, help_text=_("The URL of a Collection content source.")
     )
+    repository_version = RepositoryVersionRelatedField(
+        required=False, help_text=_("RepositoryVersion to be served"), allow_null=True
+    )
 
     def get_client_url(self, obj) -> str:
         """
@@ -255,6 +266,7 @@ class AnsibleDistributionSerializer(RepositoryVersionDistributionSerializer):
             "repository",
             "repository_version",
             "client_url",
+            "pulp_labels",
         )
         model = AnsibleDistribution
 
