@@ -20,6 +20,7 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file="collections:\n  - testing.k8s_demo_collection",
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -34,6 +35,7 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com/",
             requirements_file="collections:\n  - testing.k8s_demo_collection",
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -82,6 +84,7 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file="collections:\n  - testing.k8s_demo_collection",
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -96,6 +99,7 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file="collections:\n  - testing.k8s_demo_collection",
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -111,6 +115,7 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file=requirements_file_string,
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -125,23 +130,9 @@ class SyncTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file="INAVLID",
-        )
-        self.assertRaises(ApiException, self.remote_collection_api.create, body)
-
-    def test_sync_collection_missing_requires_ansible(self):
-        """Sync a collection with the expected `requires_ansible` data missing."""
-        body = gen_ansible_remote(
-            url="https://galaxy.ansible.com",
-            requirements_file="collections:\n  - name: inexio.thola\n    version: 1.0.0",
             sync_dependencies=False,
         )
-        remote = self.remote_collection_api.create(body)
-        self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
-
-        repo = self._create_repo_and_sync_with_remote(remote)
-
-        content = self.cv_api.list(repository_version=f"{repo.pulp_href}versions/1/")
-        self.assertGreaterEqual(len(content.results), 1)
+        self.assertRaises(ApiException, self.remote_collection_api.create, body)
 
     @unittest.skipUnless(
         "MIRROR_GALAXY" in os.environ,
@@ -174,6 +165,7 @@ class RequirementsFileVersionsTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file=requirements_file_string,
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -197,6 +189,7 @@ class RequirementsFileVersionsTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file=requirements_file_string,
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -218,6 +211,7 @@ class RequirementsFileVersionsTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file=requirements_file_string,
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
@@ -239,6 +233,7 @@ class RequirementsFileVersionsTestCase(TestCaseUsingBindings, SyncHelpersMixin):
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
             requirements_file=requirements_file_string,
+            sync_dependencies=False,
         )
         remote = self.remote_collection_api.create(body)
         self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
