@@ -6,7 +6,7 @@ import django
 django.setup()
 
 from pulpcore.plugin.tasking import (  # noqa otherwise E402: module level not at top of file
-    enqueue_with_reservation,
+    dispatch,
 )
 
 from pulp_ansible.app.tasks.test_tasks import (  # noqa otherwise E402: module level not at top of file
@@ -32,6 +32,6 @@ if __name__ == "__main__":
     for root, dirs, files in os.walk(args.collections_dir[0]):
         for file in files:
             if file.endswith(".tar.gz"):
-                async_result = enqueue_with_reservation(
+                async_result = dispatch(
                     import_collection_from_path, [], args=(os.path.join(root, file),)
                 )
